@@ -1,13 +1,14 @@
 from __future__ import annotations
 
-from svc_infra.api.fastapi import DualAPIRouter
+from svc_infra.api.fastapi.auth.sugar import public_router
+from svc_infra.api.fastapi.dual_router import DualAPIRouter
 from svc_infra.db.nosql.mongo.client import ping_mongo
 
 
 def make_mongo_health_router(
     *, prefix: str = "/_mongo/health", include_in_schema: bool = False
 ) -> DualAPIRouter:
-    router = DualAPIRouter(prefix=prefix, include_in_schema=include_in_schema)
+    router = public_router(prefix=prefix, include_in_schema=include_in_schema)
 
     @router.get("")
     async def healthcheck():
