@@ -3,6 +3,7 @@ from typing import Annotated, Any, Optional, Sequence, Type, TypeVar, cast
 from fastapi import Body, Depends, HTTPException
 from pydantic import BaseModel
 
+from svc_infra.api.fastapi.auth.sugar import public_router
 from svc_infra.api.fastapi.db.http import (
     LimitOffsetParams,
     OrderParams,
@@ -38,7 +39,7 @@ def make_crud_router_plus_sql(
     mount_under_db_prefix: bool = True,
 ) -> DualAPIRouter:
     router_prefix = ("/_sql" + prefix) if mount_under_db_prefix else prefix
-    router = DualAPIRouter(
+    router = public_router(
         prefix=router_prefix,
         tags=tags or [prefix.strip("/")],
         redirect_slashes=False,
