@@ -4,10 +4,9 @@ import logging
 
 from fastapi import Response, status
 
-from svc_infra.api.fastapi import DualAPIRouter
-
-router = DualAPIRouter()
+from svc_infra.api.fastapi import public_router
 
+router = public_router()
 ROUTER_TAG = "health"
 
 
